﻿using System.Windows;
using Telerik.Windows.Documents.Model;

namespace WpfApplication1
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            var doc = new RadDocument() { SectionDefaultPageSize = new Size(1000, 500) };
            var section1 = CreateSection(doc, GetLoremIpsum());
            var section2 = CreateSection(doc, GetLoremIpsum());
            doc.Sections.Add(section1);
            doc.Sections.Add(section2);

            this.richTb.Document = doc;

            // Option 1: Set the header using the rich textbox methods
            this.richTb.ChangeSectionHeaderLinkToPrevious(section1, HeaderFooterType.First, false);
            this.richTb.ChangeSectionHeaderLinkToPrevious(section2, HeaderFooterType.First, false);
            this.richTb.UpdateHeader(section1, HeaderFooterType.First, CreateHeader("Section 1"));
            this.richTb.UpdateHeader(section2, HeaderFooterType.First, CreateHeader("Section 2"));

            // Option 2: Set the header using the Headers property of the section
            //section1.Headers.First = CreateHeader("Section 1");
            //section2.Headers.First = CreateHeader("Section 2");          
        }

        private Header CreateHeader(string text)
        {
            var header = new Header() { };
            var doc = new RadDocument();
            var section = new Telerik.Windows.Documents.Model.Section();
            var paragraph = new Telerik.Windows.Documents.Model.Paragraph();
            paragraph.Inlines.Add(new Telerik.Windows.Documents.Model.Span(text) { FontSize = 24, FontWeight = FontWeights.Bold });
            section.Blocks.Add(paragraph);
            doc.Sections.Add(section);
            header.Body = doc;
            return header;
        }

        public Telerik.Windows.Documents.Model.Section CreateSection(RadDocument doc, string text)
        {
            var section = new Telerik.Windows.Documents.Model.Section();
            var paragraph = new Telerik.Windows.Documents.Model.Paragraph();
            paragraph.Inlines.Add(new Telerik.Windows.Documents.Model.Span(text));
            section.Blocks.Add(paragraph);
            section.HasDifferentFirstPageHeaderFooter = true;
            return section;
        }

        public string GetLoremIpsum()
        {
            return "Lorem ipsum dolor sit amet, consectetur adipiscing elit. " +
                    "Donec ante massa, ullamcorper et malesuada sed, porta id leo. " +
                    "Nulla tempor mauris in libero cursus, mattis malesuada felis pulvinar. " +
                    "Donec mollis lobortis mauris. " +
                    "Etiam feugiat, enim quis tincidunt rutrum, turpis augue vulputate dui, sit amet ullamcorper elit dolor sit amet libero. " +
                    "Donec consequat massa vel tortor aliquam, sit amet vulputate est vestibulum. " +
                    "Donec at tellus at risus rutrum consectetur ut sit amet nulla. Nulla nec nisi libero. " +
                    "Vivamus pretium convallis vehicula. Quisque ultrices risus non sodales porta. " +
                    "Pellentesque egestas, dui quis pellentesque semper, purus tortor auctor sapien, ac vestibulum nibh odio sit amet erat.";                   
        }
    }
}
